<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>AboutWindow</name>
    <message>
        <location filename="../src/aboutwindow.cpp" line="36"/>
        <source>Version</source>
        <translation>Версия</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="39"/>
        <source>Project site</source>
        <translation>Сайт проекта</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="40"/>
        <source>Developer</source>
        <translation>Разработчик</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="41"/>
        <source>Contact email</source>
        <translation>Контактный email</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="42"/>
        <source>Contact name</source>
        <translation>Контактное лицо</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="43"/>
        <source>Developer&apos;s site</source>
        <translation>Сайт разработчика</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="46"/>
        <source>Compressed modules support</source>
        <translation>Поддержка сжатых модулей</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="48"/>
        <source>NO (install &apos;unzip&apos; package for this to work)</source>
        <translation>НЕТ (установите пакет &apos;unzip&apos;, для воспроизведения сжатой модульной музыки)</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="54"/>
        <source>NO (install &apos;%1&apos; gstreamer plugin to enable equalizer)</source>
        <translation>НЕТ (установите плагин для gstreamer &apos;%1&apos; чтобы добавить поддержку эквалайзера)</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="50"/>
        <location filename="../src/aboutwindow.cpp" line="60"/>
        <source>YES</source>
        <translation>ДА</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="51"/>
        <source>Equalizer support</source>
        <translation>Поддержка эквалайзера</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="63"/>
        <source>To make more MIME types available, install appropriate gstreamer plugins</source>
        <translation>Устанавливайте соответствующие плагины для gstreamer, чтобы добавить поддержку новых форматов</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="62"/>
        <source>Supported MIME types</source>
        <translation>Поддерживаемые MIME типы</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="65"/>
        <source>Current skin</source>
        <translation>Текущий скин</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="44"/>
        <source>This project was inspired by %1.</source>
        <translation>Данный проект был вдохновлён %1.</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="73"/>
        <source>The README file for the current skin is either empty or not found.</source>
        <translation>Файл README текущего скина не найден либо пуст.</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="77"/>
        <source>The following is a contents of README file for a current skin:</source>
        <translation>Ниже приведено содержимое README файла текущего скина:</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="140"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="150"/>
        <source>App</source>
        <translation>Приложение</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="151"/>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="152"/>
        <source>Skin</source>
        <translation>Скин</translation>
    </message>
    <message>
        <location filename="../src/aboutwindow.cpp" line="153"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
</context>
<context>
    <name>EqualizerWindow</name>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="58"/>
        <source>Equalizer</source>
        <translation>Эквалайзер</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="34"/>
        <source>off</source>
        <comment>presetLabel</comment>
        <translation>выкл.</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="95"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="105"/>
        <source>kHz</source>
        <translation>кГц</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="242"/>
        <source>dB</source>
        <translation>дБ</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="262"/>
        <source>Preset</source>
        <translation>Пресет</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="304"/>
        <source>Save changes</source>
        <translation>Сохранить изменения</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="305"/>
        <source>The current preset was modified. Do you want to apply changes?</source>
        <translation>Текущий пресет был изменён. Вы хотите применить изменения?</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="331"/>
        <location filename="../src/equalizerwindow.cpp" line="342"/>
        <location filename="../src/equalizerwindow.cpp" line="351"/>
        <source>New preset</source>
        <translation>Новый пресет</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="332"/>
        <source>Enter a name for a new preset</source>
        <translation>Введите название нового пресета</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="343"/>
        <location filename="../src/equalizerwindow.cpp" line="402"/>
        <source>Preset name cannot be empty!</source>
        <translation>Название пресета не может быть пустым!</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="352"/>
        <source>Preset with such name already exists!</source>
        <translation>Пресет с таким именем уже существует!</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="364"/>
        <source>New preset has been created and selected</source>
        <translation>Новый пресет был создан и выбран</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="376"/>
        <location filename="../src/equalizerwindow.cpp" line="388"/>
        <location filename="../src/equalizerwindow.cpp" line="401"/>
        <location filename="../src/equalizerwindow.cpp" line="410"/>
        <source>Rename the preset</source>
        <translation>Переименовать пресет</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="377"/>
        <source>This is a system preset, therefore it cannot be renamed.</source>
        <translation>Это системный пресет, поэтому он не может быть переименован.</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="389"/>
        <source>Enter a new name for the current preset</source>
        <translation>Введите новое название для текущего пресета</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="411"/>
        <source>There is another preset with such name!</source>
        <translation>Такое название уже есть у другого пресета!</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="419"/>
        <source>The current preset has been renamed</source>
        <translation>Текущий пресет был переименован</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="430"/>
        <source>Save the preset</source>
        <translation>Сохранить пресет</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="431"/>
        <source>This is a system preset, therefore it cannot be saved.</source>
        <translation>Это системный пресет, поэтому он не может быть сохранён.</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="436"/>
        <source>The current preset has been updated</source>
        <translation>Текущий пресет был обновлён</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="446"/>
        <location filename="../src/equalizerwindow.cpp" line="453"/>
        <source>Delete the preset</source>
        <translation>Удалить пресет</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="447"/>
        <source>This is a system preset, therefore it cannot be deleted.</source>
        <translation>Это системный пресет, поэтому он не может быть удалён.</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="454"/>
        <source>Are you sure you want to delete the current preset?</source>
        <translation>Вы уверены, что хотите удалить текущий пресет?</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="464"/>
        <source>The current preset has been deleted</source>
        <translation>Текущий пресет был удалён</translation>
    </message>
    <message>
        <location filename="../src/equalizerwindow.cpp" line="476"/>
        <source>Select a preset</source>
        <translation>Выберите пресет</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="121"/>
        <source>Clear cache</source>
        <translation>Очистить кэш</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="122"/>
        <source>Jump to a current file</source>
        <translation>К текущему файлу</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="123"/>
        <source>File types</source>
        <translation>Типы файлов</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="127"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="725"/>
        <source>Cache has been cleared</source>
        <translation>Кэш очищен</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="764"/>
        <source>Equalizer module not found!</source>
        <translation>Модуль эквалайзера не найден!</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="781"/>
        <source>The timer has been started</source>
        <translation>Таймер запущен</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="962"/>
        <source>off</source>
        <comment>eqActionLabel</comment>
        <translation>выкл.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="965"/>
        <source>Equalizer</source>
        <translation>Эквалайзер</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1055"/>
        <source>Playback has been stopped</source>
        <translation>Воспроизведение остановлено</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1081"/>
        <source>Timer has been stopped</source>
        <translation>Таймер остановлен</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1093"/>
        <source>Timer</source>
        <translation>Таймер</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="1097"/>
        <source>off</source>
        <translation>выкл.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="126"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="130"/>
        <source>Play all files in that folder</source>
        <translation>Воспроизвести всё в этой папке</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="796"/>
        <source>searching...</source>
        <translation>ищем...</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/mainwindow.cpp" line="807"/>
        <source>found %n file(s)</source>
        <translation>
            <numerusform>нашёлся %n файл</numerusform>
            <numerusform>нашлось %n файла</numerusform>
            <numerusform>нашлось %n файлов</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>OptionsWindow</name>
    <message>
        <location filename="../src/optionswindow.cpp" line="64"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="67"/>
        <source>Playlist once</source>
        <comment>playMode</comment>
        <translation>Плэйлист без повтора</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="68"/>
        <source>Loop playlist</source>
        <comment>playMode</comment>
        <translation>Зациклить плэйлист</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="69"/>
        <source>Random</source>
        <comment>playMode</comment>
        <translation>Случайный порядок</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="70"/>
        <source>One track once</source>
        <comment>playMode</comment>
        <translation>Один трек без повтора</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="71"/>
        <source>Loop one track</source>
        <comment>playMode</comment>
        <translation>Зациклить один трек</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="74"/>
        <source>Pause</source>
        <comment>breakAction</comment>
        <translation>Поставить на паузу</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="75"/>
        <source>Stop</source>
        <comment>breakAction</comment>
        <translation>Остановить</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="76"/>
        <source>Do nothing</source>
        <comment>breakAction</comment>
        <translation>Ничего не делать</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="79"/>
        <source>Portrait</source>
        <comment>screenOrientation</comment>
        <translation>Портретная</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="80"/>
        <source>Landscape</source>
        <comment>screenOrientation</comment>
        <translation>Альбомная</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="81"/>
        <source>Auto</source>
        <comment>screenOrientation</comment>
        <translation>Автоматически</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="83"/>
        <source>Hide hidden folders</source>
        <translation>Прятать скрытые папки</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="84"/>
        <source>Always show user folders</source>
        <translation>Всегда показывать папки пользователя</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="85"/>
        <source>Hide hidden files</source>
        <translation>Прятать скрытые файлы</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="86"/>
        <source>Show only files with selected extensions</source>
        <translation>Показывать только файлы с выбранными расширениями</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="94"/>
        <source>Let a current track to end before a stop by the timer</source>
        <translation>Закончить текущий трек перед остановкой по таймеру</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="95"/>
        <source>Pushing a button or a file cancels the timer</source>
        <translation>Нажатие на кнопки или на файлы отменяет таймер</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="96"/>
        <source>Skin</source>
        <translation>Скин</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="87"/>
        <source>Play mode</source>
        <translation>Режим воспроизведения</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="88"/>
        <source>Headest unplug action</source>
        <translation>Действие при отключении наушников</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="89"/>
        <source>Resume if headset has been plugged in</source>
        <translation>Возобновить, если наушники были подключены</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="90"/>
        <source>Incoming call action</source>
        <translation>Действие при входящем вызове</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="91"/>
        <source>Resume when hang up</source>
        <translation>Возобновить при окончании вызова</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="92"/>
        <source>Pop up track titles</source>
        <translation>Всплывающие названия треков</translation>
    </message>
    <message>
        <location filename="../src/optionswindow.cpp" line="93"/>
        <source>Screen orientation</source>
        <translation>Ориентация экрана</translation>
    </message>
</context>
<context>
    <name>TimerWindow</name>
    <message>
        <location filename="../src/timerwindow.cpp" line="93"/>
        <source>Sleep timer</source>
        <translation>Таймер автоотключения</translation>
    </message>
    <message>
        <location filename="../src/timerwindow.cpp" line="98"/>
        <source>hours</source>
        <translation>часы</translation>
    </message>
    <message>
        <location filename="../src/timerwindow.cpp" line="103"/>
        <source>minutes</source>
        <translation>минуты</translation>
    </message>
    <message>
        <location filename="../src/timerwindow.cpp" line="139"/>
        <source>Start the timer</source>
        <translation>Запустить таймер</translation>
    </message>
</context>
<context>
    <name>TypesWindow</name>
    <message>
        <location filename="../src/typeswindow.cpp" line="119"/>
        <source>Displayed file types</source>
        <translation>Отображаемые типы файлов</translation>
    </message>
</context>
</TS>
